|Build Status|

Kubernetes Resource Provider
============================

The Kubernetes resource provider for Pulumi lets you use Kubernetes
resources in your cloud programs.

This package is meant for use with the Pulumi CLI. Please visit
`pulumi.io <https://pulumi.io>`__ for installation instructions.

.. |Build Status| image:: https://travis-ci.com/pulumi/pulumi-kubernetes.svg?token=eHg7Zp5zdDDJfTjY8ejq&branch=master
   :target: https://travis-ci.com/pulumi/pulumi-kubernetes
